@@ -19,6 +19,9 @@ ok(2);
 print "This can take few minutes! (1 mn on my linux PIII/700Mhz).\n" ;
 my ($p4, $p3, $p2, $p1) = ('@', '@', '@', 'A') ;
 
+use Time::HiRes qw(gettimeofday tv_interval) ;
+my $t0 = [gettimeofday];
+
 for my $base10 (1 .. 475_254) 
 	{
 	my $baseAA = "$p4$p3$p2$p1" ;
@@ -56,5 +59,8 @@ for my $base10 (1 .. 475_254)
 			
 		}
 	}
+
+my $build_time = tv_interval ($t0, [gettimeofday]) ;
+print(sprintf("Test time: %0.2f s.\n", $build_time)) ;
 	
-ok(3);
\ No newline at end of file
+ok(3);
